@@ -7,20 +7,20 @@
 #define HCX_EAPLEAP_OUT				7
 #define HCX_EAPMD5_JOHN_OUT			8
 #define HCX_TACACSP_OUT				9
-#define HCX_NMEA_OUT				10
-#define HCX_CSV_OUT				11
-#define HCX_RAW_OUT				12
-#define HCX_RAW_IN				13
-#define HCX_LTS					14
-#define HCX_LOG_OUT				15
-#define HCX_PMKID_CLIENT_OUT			16
-#define HCX_PMKID_OUT_DEPRECATED		17
-#define HCX_HCCAPX_OUT_DEPRECATED		18
-#define HCX_HCCAP_OUT_DEPRECATED		19
-#define HCX_PMKIDEAPOLJTR_OUT_DEPRECATED	20
-#define HCX_PREFIX_OUT				21
-#define HCX_ADD_TIMESTAMP			22
-#define HCX_TRACK_IN				23
+#define HCX_NMEA_IN				10
+#define HCX_NMEA_OUT				11
+#define HCX_CSV_OUT				12
+#define HCX_RAW_OUT				13
+#define HCX_RAW_IN				14
+#define HCX_LTS					15
+#define HCX_LOG_OUT				16
+#define HCX_PMKID_CLIENT_OUT			17
+#define HCX_PMKID_OUT_DEPRECATED		18
+#define HCX_HCCAPX_OUT_DEPRECATED		19
+#define HCX_HCCAP_OUT_DEPRECATED		20
+#define HCX_PMKIDEAPOLJTR_OUT_DEPRECATED	21
+#define HCX_PREFIX_OUT				22
+#define HCX_ADD_TIMESTAMP			23
 #define HCX_PMKIDEAPOL_OUT			'o'
 #define HCX_ESSID_OUT				'E'
 #define HCX_ESSIDPROBEREQUEST_OUT		'R'
@@ -40,7 +40,7 @@
 #define	OPTIONLEN_MAX			1024
 #define GPX_MAX				256
 #define NMEA_MAX			256
-
+#define NMEA_FIELD_MAX			60
 #define MAX_INTERFACE_ID		255
 
 #define RAW_LEN_MAX			131072
